# SpotDIPy
An easy way for stellar Doppler imaging of cool single stars.

A new version of SpotDIPy has been released that generates surface brightness maps for single cool stars by simultaneously modeling both spectral and light curve data using three-temperature approximation. Detailed information about the installation and usage of the code will be shared soon.

<p align="center">
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/b7701307-0c5b-4761-8b54-2a1b94c17228" width=60% height=60%>
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/2365a668-40bc-403d-aef6-f5eed17c8c4a" width=60% height=60%>
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/b47c05ae-1f48-4ebe-9cee-c78fc8509156" width=60% height=60%>
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/c5255fb6-126b-4b20-973b-9dcfdae615ab" width=60% height=60%>
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/bf52cef5-3ee0-4401-bc72-ac829b076195" width=60% height=60%>
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/87901edb-2892-4e78-b043-4d9d8d9d5145" width=60% height=60%>
<img src="https://github.com/EnginBahar/SpotDIPy/assets/122885382/cf50ca96-0a0e-46bc-82e7-6c084f114fc6" width=60% height=60%>
</p>
